@@ -15,7 +15,7 @@ from optparse import OptionParser, OptionGroup
 from PIL import Image as PImage
 from PIL import PngImagePlugin
 
-__version__ = '0.2.8'
+__version__ = '0.2.8.1'
 
 
 PADDING_REGEXP = re.compile("^(\d+-?){,3}\d+$")
@@ -1038,10 +1038,12 @@ class ConfigManager(object):
         if name in self._cache:
             return self._cache[name]
 
-        if '_%s' % name in dir(self):
-            value = self.__getattribute__('_%s' % name)()
+        try:
+            value = super(ConfigManager, self).__getattribute__('_%s' % name)()
             self._cache[name] = value
             return value
+        except AttributeError:
+            pass
 
         self._cache[name] = self.find(name)
 
